@@ -1,3 +1,5 @@
+from .async_request import AsyncRequest
+from .call_property import CallProperty
 from .core import Core
 from .custom_api import CustomAPI
 from .groups import Groups
@@ -7,6 +9,8 @@ from .websocket import WebSocket
 
 
 class Methods(
+    AsyncRequest,
+    CallProperty,
     Core,
     CustomAPI,
     Groups,
