@@ -2,6 +2,7 @@ from .b_colors import BColors
 from .generate_session import GenerateSession
 from .get_cache_id import GetCacheId
 from .get_cache_peer import GetCachePeer
+from .get_max_voice_chat import GetMaxVoiceChat
 from .get_port_server import GetPortServer
 from .run_js import RunJS
 from .spawn_process import SpawnProcess
@@ -11,6 +12,7 @@ class Core(
     GenerateSession,
     GetCacheId,
     GetCachePeer,
+    GetMaxVoiceChat,
     GetPortServer,
     SpawnProcess,
     BColors,
