@@ -1,8 +1,7 @@
 from .change_stream import ChangeStream
-from .is_playing import IsPlaying
 from .pause_stream import PauseStream
 from .resume_stream import ResumeStream
 
 
-class Stream(ChangeStream, IsPlaying, PauseStream, ResumeStream):
+class Stream(ChangeStream, PauseStream, ResumeStream):
     pass
