@@ -23,14 +23,6 @@ class ApiBackend:
                 result_json = {
                     'result': 'ACCESS_GRANTED',
                 }
-                if params['action'] == 'join_call':
-                    self.pytgcalls._current_active_chats.append(
-                        params['chat_id'],
-                    )
-                elif params['action'] == 'leave_call':
-                    self.pytgcalls._current_active_chats.remove(
-                        params['chat_id'],
-                    )
         except Exception:
             pass
         return web.json_response(result_json)
