@@ -20,16 +20,14 @@ class ChangeVolumeVoiceCall:
         if params['session_id'] == self.pytgcalls._session_id:
             # noinspection PyBroadException
             try:
-                chat_call = (
-                    await self.pytgcalls._load_full_chat(
-                        params['chat_id'],
-                    )
-                ).full_chat.call
+                chat_call = await self.pytgcalls._load_chat_call(
+                    params['chat_id'],
+                )
                 await self.pytgcalls._app.send(
                     EditGroupCallParticipant(
                         call=chat_call,
                         participant=self.pytgcalls._cache_user_peer[
-                            int(params['chat_id']),
+                            int(params['chat_id'])
                         ],
                         muted=False,
                         volume=params['volume'] * 100,
