@@ -13,14 +13,13 @@ class UpdateCallData:
         params = await request.json()
         if isinstance(params, str):
             params = json.loads(params)
-
         chat_id = int(params['chat_id'])
-
         if params['result'] == 'PAUSED_AUDIO_STREAM':
             self.pytgcalls._set_status(chat_id, 'paused')
         elif params['result'] == 'RESUMED_AUDIO_STREAM':
             self.pytgcalls._set_status(chat_id, 'playing')
-        elif params['result'] == 'JOINED_VOICE_CHAT':
+        elif params['result'] == 'JOINED_VOICE_CHAT' or \
+                params['result'] == 'CHANGED_AUDIO_STREAM':
             self.pytgcalls._add_active_call(params['chat_id'])
             self.pytgcalls._add_call(chat_id)
             self.pytgcalls._set_status(chat_id, 'playing')
